@@ -560,6 +560,7 @@ class FFPuppet:
                         )
                 # collect logs (excluding minidumps)
                 for fname in self._crashreports(skip_md=True, skip_benign=False):
+                    # pylint: disable=consider-using-with
                     self._logs.add_log(basename(fname), open(fname, "rb"))
                 # check for minidumps in the profile and dump them if possible
                 process_minidumps(
@@ -570,7 +571,7 @@ class FFPuppet:
                 )
                 if self._logs.get_fp("stderr"):
                     self._logs.get_fp("stderr").write(
-                        ("[ffpuppet] Reason code: %s\n" % r_code).encode("utf-8")
+                        ("[ffpuppet] Reason code: %s\n" % r_code.name).encode("utf-8")
                     )
         # reset remaining to closed state
         try:
@@ -587,7 +588,7 @@ class FFPuppet:
             finally:
                 self.profile = None
         finally:
-            LOG.debug("exit %s", r_code)
+            LOG.debug("reason code: %s", r_code.name)
             self.reason = r_code
 
     def cpu_usage(self):
@@ -633,7 +634,7 @@ class FFPuppet:
                   in a valid functioning state otherwise False.
         """
         if self.reason is not None:
-            LOG.debug("reason is set to %r", self.reason)
+            LOG.debug("reason is set to %r", self.reason.name)
             return False
         if not self.is_running():
             LOG.debug("is_running() returned False")
@@ -872,7 +873,7 @@ class FFPuppet:
             logs_only=logs_only,
             meta=meta,
             bin_path=self._bin_path,
-            rr_pack=self._dbg == Debugger.RR,  # pernosco-submit performs packs
+            rr_pack=self._dbg in (Debugger.PERNOSCO, Debugger.RR),
         )
 
     def wait(self, timeout=None):
