@@ -4,7 +4,7 @@
 """ffpuppet minidump parsing module"""
 
 from logging import getLogger
-from os import getenv, scandir
+from os import getenv, scandir, stat
 from os.path import getmtime, isdir
 from os.path import join as pathjoin
 from shutil import copy, copyfileobj
@@ -30,10 +30,7 @@ class MinidumpParser:  # pylint: disable=missing-docstring
     )
 
     def __init__(self, scan_path, record_failures=True, working_path=None):
-        self.md_files = list()
-        for entry in scandir(scan_path):
-            if entry.name.endswith(".dmp"):
-                self.md_files.append(entry.path)
+        self.md_files = [x.path for x in scandir(scan_path) if x.name.endswith(".dmp")]
         self.symbols_path = None
         self._include_raw = getenv("FFP_DEBUG_MDSW") is not None
         self._record_failures = record_failures  # mdsw failure reporting
@@ -76,7 +73,13 @@ class MinidumpParser:  # pylint: disable=missing-docstring
                     with open(pathjoin(report_dir, "mdsw_stdout.txt"), "wb") as log_fp:
                         copyfileobj(out_fp, log_fp, 0x10000)
                     LOG.warning("mdsw logs can be found here %r", report_dir)
-                    raise RuntimeError("MDSW Error")
+                # collect size of dmp file to help diagnose mdsw issues
+                try:
+                    dmp_size = stat(dump_file).st_size
+                except OSError:
+                    dmp_size = None
+                raise RuntimeError("MDSW Error (dmp size: %r)" % (dmp_size,))
+
         out_fp.seek(0)
 
     def _read_registers(self, dump_file, log_fp):
@@ -108,12 +111,14 @@ class MinidumpParser:  # pylint: disable=missing-docstring
                 log_fp.write(line)
             LOG.debug("collected register info: %r", found_registers)
 
-    def _read_stacktrace(self, dump_file, log_fp, raw_fp=None):
+    def _read_stacktrace(self, dump_file, log_fp, raw_fp=None, limit=MDSW_MAX_STACK):
         """Use minidump_stackwalk to retrieve stack trace from dump_file.
 
         Args:
             dump_file (str): Path to dmp file.
-            out_fp (file): File to write output to.
+            log_fp (file): File to write output to.
+            raw_fp (file): File to write unprocessed output to.
+            limit (int): Maximum number of lines to include in stack trace.
 
         Returns:
             None
@@ -145,11 +150,9 @@ class MinidumpParser:  # pylint: disable=missing-docstring
 
                 log_fp.write(line)
                 line_count += 1
-                if line_count >= self.MDSW_MAX_STACK:
-                    LOG.warning(
-                        "MDSW_MAX_STACK (%d) limit reached", self.MDSW_MAX_STACK
-                    )
-                    log_fp.write(b"WARNING: Hit line output limit!")
+                if line_count >= limit:
+                    LOG.warning("Stack size limit reached (%d)", limit)
+                    log_fp.write(b"WARNING: Hit stack size output limit!")
                     break
 
     def collect_logs(self, cb_create_log, symbols_path):
